# This function finds the optimal scaling paramter, theta, used in the
# Inverse Hyperbolic Sine (IHS) transformation. The IHS transformation is used
# with net worth data in the May Symposium paper, "College is not Enough." The
# optimal parameter is identified by maximizing the concetrated log-likelihood
# equation using Maximum Likelihood Estimation. This script was written by
# Lowell Ricketts.

ihs.loglik <- function(theta, depvar, indvars, weight = NULL) {
        if (!is.null(weight)) {
                df <- data.frame(depvar, indvars, weight)  
        } else {
                df <- data.frame(depvar, indvars)      
        }
        
        # Use theta in IHS transformed dependent variable
        g <- log((theta * df$depvar) + sqrt((theta^2) * (df$depvar ^ 2) + 1))/theta
        n <- length(df$depvar)
        
        # Regress g on indepedent variables
        if (!is.null(weight)){
                wgtsum <- sum(df$weight)
                normwgt <- n * weight/wgtsum
                mdl <- lm(g ~ . - depvar - weight, weights = weight, data = df)
                # Pull out weighted SSR from model
                mdl.SSR <- sum(normwgt * (mdl$residuals ^ 2))
                # Weighted second component in log-likehood function
                g <- sum(normwgt * log(1 + (theta^2) * (depvar^2)))
                
        } else {
                mdl <- lm(g ~ . - depvar, data = df)
                # Pull out SSR from model
                mdl.SSR <- sum(mdl$residuals ^ 2)
                #g is the second component in the concentrated log-likehood equation
                g <- sum(log(1 + (theta^2) * (depvar^2)))
        }
        
        ll <- -(n/2) * log(mdl.SSR) - 0.5 * g # Evaluate log-likelihood
        return(ll)
}